@@ -88,13 +88,13 @@ _maix_display_module = Pybind11Extension(
     ],
 )
 
-max_nn_srcs = get_srcs('ext_modules/_maix_nn/src')
+max_nn_srcs = get_srcs('ext_modules/_maix_nn_mdsc/src')
 max_nn_srcs.extend(get_srcs('ext_modules/libmaix/components/libmaix/src'))
 max_nn_srcs.remove("ext_modules/libmaix/components/libmaix/src/libmaix.c")
-_maix_nn_module = Extension('_maix_nn', include_dirs=['ext_modules/_maix_nn/include', 'ext_modules/libmaix/components/libmaix/include'],
+_maix_nn_module = Extension('_maix_nn', include_dirs=['ext_modules/_maix_nn_mdsc/include', 'ext_modules/libmaix/components/libmaix/include'],
                             sources=max_nn_srcs,
                             libraries=[
-    "maix_utils", "maix_nn", "maix_nn_decoder", "maix_nn_app"
+    "maix_utils", "maix_nn", "maix_nn_app"
 ],
     library_dirs=[ ext_so, ],
     # extra_link_args  = [ "-Wl,-z,origin", "-Wl,-rpath='$ORIGIN/maix'" ]
@@ -134,12 +134,10 @@ _maix_speech_module = Pybind11Extension("_maix_speech",
 _maix_nn_decode_retinaface_module =Pybind11Extension(
     name = '_maix_nn_decoder_retinaface',
     include_dirs=['ext_modules/libmaix/components/libmaix/include'],
-    sources=get_srcs("ext_modules/_maix_nn_decoder"),
+    sources=['ext_modules/_maix_nn_decoder/py_maix_nn_decoder_retinaface.cpp','ext_modules/libmaix/components/libmaix/src/decoder/decoder_retinaface.c'] ,
     libraries=[
         "pthread",
-        # "maix_utils",
         "maix_nn",
-        "maix_nn_decoder",
     ],
     library_dirs=[ ext_so, ],
     # library_dirs=["/lib",  "/usr/lib", ext_so, ],
