@@ -40,12 +40,36 @@ py::tuple _get_string_size(std::string str, double scale, int thickness)
   return py::make_tuple(w, h);
 }
 
+maix_image *_image_new(std::vector<int> size, std::vector<int> color, std::string mode)
+{
+  auto tmp = new maix_image();
+  tmp->_new(size, color, mode);
+  return tmp;
+}
+
+maix_image *_image_load(py::object data, std::vector<int> size, std::string mode)
+{
+  auto tmp = new maix_image();
+  tmp->_load(data, size, mode);
+  return tmp;
+}
+
+maix_image *_image_open(std::string path)
+{
+  auto tmp = new maix_image();
+  tmp->_open_file(path);
+  return tmp;
+}
+
 PYBIND11_MODULE(_maix_image, mo)
 {
     // mode_init();         //模块的初始化函数
     mo.def("load_freetype", _load_freetype, py::arg("path"), py::arg("fontHeight") = 14)
       .def("free_freetype", _free_freetype)
-      .def("get_string_size", _get_string_size, py::arg("str"), py::arg("scale") = 1.0, py::arg("thickness") = 1);
+      .def("get_string_size", _get_string_size, py::arg("str"), py::arg("scale") = 1.0, py::arg("thickness") = 1)
+      .def("new", _image_new, py::arg("size") = std::vector<int>{240, 240}, py::arg("color") = std::vector<int>{0, 0, 0}, py::arg("mode") = "RGB")
+      .def("load", _image_load, py::arg("data"), py::arg("size") = std::vector<int>{240, 240}, py::arg("mode") = "RGB")
+      .def("open", _image_open, py::arg("str"));
 
     pybind11::class_<maix_image::maix_histogram>(mo, "histogram")
         .def(pybind11::init<>())
@@ -102,14 +126,17 @@ PYBIND11_MODULE(_maix_image, mo)
         .def("draw_circle", &maix_image::_draw_circle, py::arg("x"), py::arg("y"), py::arg("radius"), py::arg("color") = std::vector<int>{127, 127, 127}, py::arg("thickness") = 1)
         .def("draw_ellipse", &maix_image::_draw_ellipse, py::arg("cx"), py::arg("xy"), py::arg("rx"), py::arg("ry"), py::arg("angle"), py::arg("startAngle"), py::arg("endAngle"), py::arg("color") = std::vector<int>{127, 127, 127}, py::arg("thickness") = 1)
         .def("draw_string", &maix_image::_draw_string, py::arg("x"), py::arg("y"), py::arg("str"), py::arg("scale") = 1.0, py::arg("color") = std::vector<int>{127, 127, 127}, py::arg("thickness") = 1)
-        .def("rotate", &maix_image::_rotate, py::arg("rotate"), py::arg("adjust") = 0)
+        .def("rotate", &maix_image::_rotate, py::arg("angle"), py::arg("adjust") = 0)
+        .def("flip", &maix_image::_flip, py::arg("flip") = 1)
         .def("convert", &maix_image::_convert, py::arg("mode") = "RGB")
+        .def("cut", &maix_image::_draw_crop, py::arg("x"), py::arg("y"), py::arg("w"), py::arg("h"))
         .def("crop", &maix_image::_draw_crop, py::arg("x"), py::arg("y"), py::arg("w"), py::arg("h"))
         .def("draw_image", &maix_image::_draw_image, py::arg("img"), py::arg("x") = 0, py::arg("y") = 0, py::arg("alpha") = -1.)
+        .def("paste", &maix_image::_draw_image, py::arg("img"), py::arg("x") = 0, py::arg("y") = 0, py::arg("alpha") = -1.)
         .def("show", &maix_image::_show)
         .def("get_pixel", &maix_image::_get_pixel, py::arg("x"), py::arg("y"))
         .def("set_pixel", &maix_image::_set_pixel, py::arg("x"), py::arg("y"), py::arg("color"))
-        //maix_image继承maix_version方法
+        //maix_image继承maix_vision方法
         .def("get_blob_lab", &maix_image::get_blob_color_max, py::arg("roi") = std::vector<int>{0, 0, 0, 0}, py::arg("critical") = 0, py::arg("co") = 0)
         .def("get_blob_color", &maix_image::get_blob_color_max, py::arg("roi") = std::vector<int>{0, 0, 0, 0}, py::arg("critical") = 0, py::arg("co") = 0)
         .def("find_blob_lab", &maix_image::_maix_vision_find_blob, py::arg("thresholds"), py::arg("roi") = std::vector<int>{0, 0, 0, 0}, py::arg("x_stride") = 2, py::arg("y_stride") = 2, py::arg("invert") = 0, py::arg("area_threshold") = 10, py::arg("pixels_threshold") = 10, py::arg("merge") = 0, py::arg("margin") = 0, py::arg("tilt") = 0, py::arg("co") = 1)
