@@ -1,15 +1,23 @@
 
 
+
+
+#define debug_line  //printf("%s:%d %s %s %s \r\n", __FILE__, __LINE__, __FUNCTION__, __DATE__, __TIME__)
+
+// int *steps = NULL; // config->steps;
+// int *min_sizes = NULL; // config->min_sizes;
+
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #include <math.h>
 #include "libmaix_nn_decoder_retinaface.h"
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
 
-#define debug_line  //printf("%s:%d %s %s %s \r\n", __FILE__, __LINE__, __FUNCTION__, __DATE__, __TIME__)
 
-// int *steps = NULL; // config->steps;
-// int *min_sizes = NULL; // config->min_sizes;
 int min_size_len = MIN_SIZE_LEN;
 int anchor_size_len = ANCHOR_SIZE_NUM;
 
@@ -474,3 +482,6 @@ void libmaix_nn_decoder_retinaface_destroy(libmaix_nn_decoder_t** obj)
     }
     *obj = NULL;
 }
+#ifdef __cplusplus
+}
+#endif
\ No newline at end of file
