@@ -367,14 +367,13 @@ extern "C"
       if (!libmaix_font::is_load)
       {
         cv::Size textSize = cv::getTextSize(text, cv::FONT_HERSHEY_PLAIN, scale, thickness, &baseline);
-        int tmp = baseline - (scale * thickness);
-        *width = textSize.width * scale, *height = textSize.height + tmp;
+        *width = textSize.width * scale, *height = textSize.height + baseline - (scale * thickness);
         // printf("old textSize w %d h %d b %d\r\n", textSize.width, textSize.height, baseline);
       }
       else
       {
         cv::Size textSize = libmaix_font::ft->getTextSize(text, libmaix_font::fontHeight, thickness, &baseline);
-        *width = textSize.width * scale, *height = libmaix_font::fontHeight * scale;
+        *width = textSize.width * scale, *height = libmaix_font::fontHeight * scale + thickness;
         // printf("new textSize w %d h %d b %d\r\n", textSize.width, textSize.height, baseline);
       }
   }
@@ -406,13 +405,12 @@ extern "C"
     {
       cv::Size textSize = cv::getTextSize(text, cv::FONT_HERSHEY_PLAIN, scale, thickness, &baseline);
       // printf("old textSize w %d h %d b %d\r\n", textSize.width, textSize.height, baseline);
-      int tmp = baseline - (scale * thickness);
-      cv::putText(input, text, cv::Point(x, y + textSize.height + tmp), cv::FONT_HERSHEY_PLAIN, scale,
+      cv::putText(input, text, cv::Point(x, y + textSize.height + baseline - (scale * thickness)), cv::FONT_HERSHEY_PLAIN, scale,
           cv::Scalar(color.rgb888.r, color.rgb888.g, color.rgb888.b, color.rgb888.a), thickness);
     }
     else
     {
-      cv::Size textSize = libmaix_font::ft->getTextSize(text, libmaix_font::fontHeight, thickness, &baseline);
+      // cv::Size textSize = libmaix_font::ft->getTextSize(text, libmaix_font::fontHeight, thickness, &baseline);
       // printf("new textSize w %d h %d b %d\r\n", textSize.width, textSize.height, baseline);
       libmaix_font::ft->putText(input, text, cv::Point(x, y), libmaix_font::fontHeight * scale,
           cv::Scalar(color.rgb888.r, color.rgb888.g, color.rgb888.b, color.rgb888.a), -1, 16, false);
@@ -870,6 +868,28 @@ LIBMAIX_IMAGE_MODE_BGR888 -> LIBMAIX_IMAGE_MODE_BGR888   :      2056
     return LIBMAIX_ERR_NONE;
   }
 
+  libmaix_err_t libmaix_cv_image_flip(libmaix_image_t *src, int flipCode)
+  {
+    libmaix_err_t err = LIBMAIX_ERR_NONE;
+    if (src->width == 0 || src->height == 0 || src->data == NULL)
+    {
+      return LIBMAIX_ERR_PARAM;
+    }
+    // -------------------------------
+    if (src->mode == LIBMAIX_IMAGE_MODE_RGB888)
+    {
+      cv::Mat cv_src(src->height, src->width, CV_8UC3, src->data);
+      cv::flip(cv_src, cv_src, flipCode);
+    }
+    else
+    {
+      LIBMAIX_IMAGE_ERROR(LIBMAIX_ERR_NOT_IMPLEMENT);
+      return LIBMAIX_ERR_NOT_IMPLEMENT;
+    }
+    // -------------------------------
+    return LIBMAIX_ERR_NONE;
+  }
+
   libmaix_image_color_t libmaix_cv_image_get_pixel(libmaix_image_t *src, int x, int y)
   {
     libmaix_image_color_t val;
